@@ -29,8 +29,7 @@
 
 extern
 int
-client_connect_inet(const char *host, const char *port, int stream,
-                    int timeout);
+client_connect_inet(const char *host, const char *port, int timeout);
 
 extern
 int
